import axios from 'axios'
import router from '@/router'
import { ElMessage } from 'element-plus'
ElMessage

/**
* @description:发送Axios请求
*/
const request = axios.create({
  baseURL: '/api',
  timeout: 5000
})

// 请求拦截器
request.interceptors.request.use(
  function (config) {
    // 给所有授权的请求提供token
    const AccessToken = localStorage.getItem("AccessToken")
    if (AccessToken) {
      config.headers.token = AccessToken
    }
    return config
  },
  function (error) {
    // 操作
    return Promise.reject(error)
  }
)

// 响应拦截器
request.interceptors.response.use(
  function (response) {
    let code = response.data.code
    // 当token过期或损坏时
    if (code == 1052) {
      router.push("/login");
      ElMessage.error("登录过期，请重新登录！");
      return

      // 弹出错误
    } else if (code != 200) {
      if (code == 1053) {
        router.push("/login");
        // Toast.fail("请您先登录！");
        return

      } else if (code == 500) {
        ElMessage.error("系统异常，请稍后再试");

        // 其他错误
      } else {

        return Promise.reject(response.data)
      }
    } else {
      // 正常返回
      return response.data
    }

  },
  function (error) {
  }
)

export default request